alpaca-llama
============
# alpaca
将一个描述词法的正则表达式转换成最小化的DFA，以dot语言形式输出。

# llama
将描述语法的范式转换成分析转换表，以图形的方式输出，同时能够根据不同的语法分析算法检查范式的定义错误，并且能够修正错误。

详情请参考[alpace-llama wiki](https://github.com/activesys/alpaca-llama/wiki)。
